Angles consist of two rays with the same endpoint and are typically measured in standard position. Standard position is when one of the rays, referred to as the initial side starts at the origin and extend outwards along the $x$ axis, with a second ray referred to as the terminal side.

If an angle is measured counterclockwise, it's a *positive angle*, and if an angle is measured clockwise, it's a *negative angle*. 

## Degrees and Radians
To convert **from radians to degrees**, multiply the radian value by $\frac{180\degree}{\pi}$.
$$ x * \frac{180\degree}{\pi}$$
To convert **from degrees to radians**, multiply the degree measure by $\frac{\pi}{180\degree}$. 
$$ x * \frac{\pi}{180\degree} $$

## Complementary and Supplementary Angles
A **complimentary** angle is formed when two positive angles add up to $90\degree$ or $\frac{\pi}{2}$. One mnemonic device that you can use to remember this is: 

> Complementary starts with C, and C stands for corner. $90\degree$ makes a corner.

A **supplementary** angle is formed when two positive angles add up to $180\degree$ or $\pi$. One mnemonic device that you can use to remember this is:

> Supplementary starts with S and S stands for straight. $180\degree$ makes a straight line.

Angles greater than $90\degree$ have no complement and angles greater than $180\degree$ have no supplement.

# Triangles
Triangles are typically notated using $A$, $B$, and $C$ for the angles of a triangle, and $a$, $b$, and $c$ for the sides of a triangle. $C$ will always be the right angle, and $c$ will always refer to the hypotenuse, but $A$/$a$ and $B$/$b$ are used interchangeably. 

For any valid triangle, all three angles will *always* add up to $180\degree$.

$$ \angle A + \angle B + \angle C = 180 $$

## Right Angle Triangle Trigonometry

| SohCahToa                                     | Inverse                                       |
| --------------------------------------------- | --------------------------------------------- |
| $$ sin\theta = \frac{opposite}{hypotenuse} $$ | $$ csc\theta = \frac{hypotenuse}{opposite}$$  |
| $$ cos\theta = \frac{adjacent}{hypotenuse} $$ | $$ sec\theta = \frac{hypotenuse}{adjacent} $$ |
| $$ tan\theta = \frac{opposite}{adjacent} $$   | $$ cot\theta = \frac{adjacent}{opposite} $$   |
These rules apply regardless of the orientation of the triangle. 

Cosecant, secant, and tangent are inverses of sine, cosine, and tangent respectively, and so they can be found by taking $\frac{1}{x}$, where $x$ is the function you'd like to find the inverse of.

## Angle of Elevation/Depression
- The **angle of elevation** is the angle between the hypotenuse and the bottom line. As an example, if a ladder was leaning against a building, the angle of elevation would be the angle where the ladder intersects with the ground, and it would be the angle between the ladder and the ground.
- The **angle of depression** is the angle between the top of the hypotenuse and an (often imaginary) horizontal line. 
# Definitions
| Term                 | Description                                                                                                                                                                                                                                                                          |
| -------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------ |
| Ray                  | Directed line segment consisting of an endpoint and a direction. Notated as $\overrightarrow{EF}$, where $E$ denotes the endpoint and $F$ denotes a point along the ray.                                                                                                             |
| Angle                | Union of two rays with a common endpoint. Notated as $\angle DEF$ or $\angle FED$, where $D$ and $F$ are along the points of each ray, and $E$ is the vertex. $\angle EFD$ is not valid notation, because the vertex must be the middle.                                             |
| $\theta$             | A lowercase theta is used to represent a (non right) angle in a triangle                                                                                                                                                                                                             |
| $\phi$               | A lowercase phi is used to represent another unknown angle in a triangle. As an example, in an algebraic equation, $x$ might be used to represent the first unknown and $y$ the second. In trig, $\theta$ would be used to represent the first unknown angle, and $\phi$ the second. |
| Initial side         | In standard position, the initial side is the ray that extends from the origin along the $x$ axis.                                                                                                                                                                                   |
| Terminal side        | In standard position, the terminal side is the ray that's being measured relative to the initial side.                                                                                                                                                                               |
| $s$                  | The length of a curve along the radius.                                                                                                                                                                                                                                              |
| Radian               | Denoted with $rad$, one radian is equal to the radius, but it's measured along the arc in a curve instead of from the center.                                                                                                                                                        |
| Complementary Angles | Two positive angles that add up to $90\degree$ or $\frac{\pi}{2}$. One mnemonic device that you can use to remember this is: <br><br>Complementary starts with C, and C stands for corner. $90\degree$ makes a corner.                                                               |
| Supplementary Angles | Two positive angles that add up to $180\degree$ or $\pi$. One mnemonic device that you can use to remember this is:<br><br>Supplementary starts with S and S stands for straight. $180\degree$ makes a straight line.                                                                |
| Hypotenuse           | The side opposite the right angle in a triangle.                                                                                                                                                                                                                                     |
| Opposite             | For a given angle $\theta$ in a right triangle, this is the side that does not touch that angle.                                                                                                                                                                                     |
| Adjacent             | For a given angle $\theta$ in a right triangle, this side makes up the side of the intersection opposite the hypotenuse.                                                                                                                                                             |
