An **identity** is an equation that is true for all values of the variable for which the expressions in the equation are defined.
# Trigonometric Identities

All of the following only apply when the denominator is not equal to zero.

$$ tan \theta = \frac{y}{x} $$
Because the following are inverses of their counterparts, you only need to remember the equivalents for $sin$, $cos$, and $tan$, then just find the inverse by taking $1/v$. 

| Base Identity                 | Inverse Identity               | Alternate Identities                          | Alternate Inverse Identities                                          |
| ----------------------------- | ------------------------------ | --------------------------------------------- | --------------------------------------------------------------------- |
| $$ sin\theta = y $$           | $$ csc\theta = \frac{1}{y} $$  |                                               | $$ csc\theta = \frac{1}{sin\theta} $$                                 |
| $$ cos\theta = x $$           | $$ sec \theta = \frac{1}{x} $$ |                                               | $$ sec\theta = \frac{1}{cos\theta} $$                                 |
| $$ tan\theta = \frac{y}{x} $$ | $$ cot\theta = \frac{x}{y} $$  | $$ tan\theta = \frac{sin\theta}{cos\theta} $$ | $$ cot\theta = \frac{1}{tan\theta} = \frac{cos\theta}{sin{\theta}} $$ |
# Pythagorean Identities
The Pythagorean identity expresses the Pythagorean theorem in terms of trigonometric functions. It's a basic relation between the sine and cosine functions.
$$ sin^2 \theta + cos^2 \theta = 1 $$
There are more forms that are useful, but they can be derived from the above formula:
$$ 1 + tan^2\theta = sec^2\theta $$
$$ cot^2 \theta + 1 = csc^2\theta $$
# Even and Odd Identities
- A function is even if $f(-x) = f(x)$.
- A function is odd if $f(-x) = -f(x)$
- Cosine and secant are **even**
- Sine, tangent, cosecant, and cotangent are **odd**.
## Examples
### Even and Odd Functions
> If $cot\theta = -\sqrt{3}$, what is $cot(-\theta)$? 

$cot$ is an odd function, and so $cot(-\theta) = \sqrt{3}$
### Simplifying Using Identities
> Simplify $\frac{sin\theta}{cos\theta}$

1. The above equation can be split into two components
$$ \frac{sin\theta}{cos\theta} = \frac{sin\theta}{1} * \frac{1}{csc\theta} $$
2. Referring to the list of trig identities, we know that $\frac{1}{csc\theta}$ is equal to $sin\theta$. 
$$ \frac{sin\theta}{1} * \frac{1}{csc\theta} = sin\theta * sin\theta $$
3. Simplifying further, we get:
$$ sin^2\theta $$
### Finding all values using identities
If $sec\theta = -\frac{25}{7}$ and $0 < \theta < \pi$, find the values of the other 5 trig functions:

1. To find $tan\theta$, we can use the trig identity  $1 + tan^2\theta = sec^2\theta$:
$$ 1 + tan^2\theta = (-\frac{25}{7})^2 $$
Shuffling things around, we get this:
$$ tan^2\theta = \frac{625}{49} - 1 $$

Performing that subtraction gives us this:
$$ \frac{625}{49} - \frac{49}{49} = \frac{576}{49} = tan^2\theta $$
You can get rid of the exponent:

$$ \sqrt{\frac{576}{49}} = tan\theta $$
$\sqrt{576} = 24$ and $\sqrt{49} = 7$, so:
$$ tan\theta = \frac{24}{7} $$
2. To find $cos\theta$, because $sec$ is the inverse of $cos$, we can use the identity $sec\theta = \frac{1}{cos\theta}$:
$cos\theta = -\frac{7}{25}$

3. To find $sin\theta$, we can use the trig identity $sin^2\theta + cos^2\theta = 1$:
$$ sin^2\theta + (-\frac{7}{25}) = 1 $$
Rearranging, we get:
$$ 1 - (-\frac{7}{25})^2 = sin^2\theta $$
Applying the exponent gives us $\frac{49}{625}$, so we can do this:
$$ \frac{625}{625} - \frac{49}{625} = \frac{576}{625} = sin^2\theta $$

Getting rid of the exponent:
$$ \sqrt{\frac{576}{625}} = \frac{24}{25} = sin\theta $$

From there, you can find the rest of the identities fairly easily.

# Simplifying trig expressions using identities
Given the difference of square formula:
$$ a^2 - b^2 = (a-b)(a+b) $$

## Examples
Simplify $\tan\theta\sin\theta + \cos\theta$:
1. $\dfrac{\sin\theta}{\cos\theta} * \sin\theta + \cos\theta$
2. $\dfrac{\sin^2\theta}{cos\theta} + \cos\theta$
3. $(\dfrac{\sin^2\theta}{cos\theta} + \cos\theta)\dfrac{\cos\theta}{\cos\theta} = \sin^2\theta*\cos^2\theta + \cos\theta$ 

Si\