## Understanding **must** precede advice
When beginning a conversation, the goal should be understanding, not problem solving. You should aim to make sure there's a *mutual understanding* of the situation before attempting to problem solve. Problem solving and advice should *only* begin when both people feel totally understood, and heard.
# Skills
There are a few skills that can massively contribute to a healthy relationship. It takes work and practice to refine them.
## Putting Your Feelings into Words
When people are able to find the right images, phrases, metaphors, and words to adequately describe our feelings, there's a kind of "resolution" that comes of it, an easing of tension. In conversation, focusing on finding the right way to explain your feelings can make the conversation more intimate, and more productive, because you can convey your feelings to the other person in a more impactful way.
## Asking Open-Ended Questions
The ability to ask open ended questions can help the other person explore their feelings by asking open-ended questions. This can be done by asking targeted questions, looking to understand their feelings about something, and by making specific statements that encourage the other person to expand on a statement further.
## Expressing Empathy
Empathy *is not easy*. In a difficult conversation, it's important to try to learn more about, explore, and learn more about another person's thoughts, feelings, and needs. Empathy communicates to the other person that their thoughts, feelings, and needs make sense to you, and that you understand them. It doesn't necessarily mean you agree, but it means showing them that their perception of the situation is valid. You can have your own perception of the situation that's different from theirs, but both of your perceptions can be valid.

---

# Crucial Conversations
Below are my notes and thoughts from reading the book *Crucial Conversations.

The fundamental idea behind the book is that:
> The root cause of many ... human problems lies in how people behave when we disagree about high-stakes, emotional issues.

You know you're getting into a crucial conversation as opposed to a normal conversation when:
- Opinions vary, people feel differently about things.
- The stakes are high, the outcome of the conversation matters.
- Emotions are high, people feel strongly about the outcome.

One important factor in problem resolution is the time that passes between when the problem emerges, and when resolution is attempted. The impact of the issues, and the difficulty of resolution grow when the issue is left unresolved. It can lead to gossiping, mistrust, and resentment. 

It's important to try to resolve problems *quickly* after they are identified.

### How do we handle crucial conversations?
There are 3 broad options:
- We can avoid them entirely.
- We can face them and handle it poorly.
- We can face them and handle it well.

While only one of these options reliably leads to an effective outcome, you'll often find that we often fall back to the first two because of the fear that engagement will make the issue worse. 

*personal note*: Humans inherently dislike being uncomfortable, the root instinct to avoid immediate discomfort in any way is natural . But in so many parts of life, if you push through that, the outcome will be very positive. Try to be mindful of anything that makes you uncomfortable, and ask yourself, "will my life improve if I do this hard thing?"

If you fail to discuss these issues with other people, *those issues will become the lens through which you see them*, which will show up in the way you treat the other person.

We generally handle important conversations *poorly*, strong emotions make people worse at communicating effectively, not better. Our natural instincts are to push back against that communication because it's hard, and it triggers our fight or flight instincts. This means we won't be receptive to new information, and we'll likely respond in a way that's not irrational and hurts the situation for both parties. It usually takes conscious effort to be mindful of your thoughts and feelings, process them fully and rationally, then respond to the other party in a rational way.

*personal note*: When we get emotional, the *limbic system* in our brain begins to take control. We stop being rational, and we literally do not process things with the same amount of brainpower that we'd use normally. This is why it's so important to recognize when you're emotional, and why it's important to avoid letting conversations get ruled by emotion.

### Dialogue
A healthy conversation should involve two way communication. You need to make sure the other person is given the space to make themself understood. 

When meaning and ideas can flow freely, people are often more receptive to ideas and change. When everyone can contribute their feelings to the discussion, people involved can form a clearer picture of the circumstances, and when everyone has a clear understanding, then they're more likely to personally commit to the outcome of the discussion.
### Topics
Difficult conversations are most successful when they're focused on a single issue. Because human interactions are inherently complex, focusing **a conversation on a single topic takes effort**. 

When faced with the time to pick a topic, there are a few common mistakes:
- Picking an easier topic over the hard topic: It's natural to have a bias to choose a topic you think you can win with. That usually means picking an easier topic than the root issue.
- Choosing a more recent event over the most important one: We tend to focus on the most recent event or behavior rather than the one that matters the most. This often happens because you remember recent events more clearly, and you don't want to be accused of "dredging up ancient history".

Making these mistakes can lead to fairly predictable results: you end up having the wrong conversation and not addressing the actual issue. **A few ways ways to identify that you're having the wrong conversation include**:
- **Your emotions escalate**: When you're having the wrong conversation, even if the conversation is going well, you'll probably begin to notice frustration building as the conversation progresses, because there's something important that needs to be addressed.
- **You walk away skeptical**: If you find yourself feeling like real change will not take place, or that you got to an agreement but doubt that the changes made will solve the real problem, you might have missed addressing the real problem entirely.
- **You feel deja vu**: If you feel like you're repeating a conversation with the same people again, the problem is not them, it's you. You're having the wrong conversation about the wrong topic, and so the problem isn't fixed.

One of the best ways to ensure you're talking about the right topic is to get good at noticing when you're actually talking about the wrong one.

#### Choosing the right topic
There are a few skills that can help you figure out the right issue, and in turn lead to you having the right conversation.

**Unbundling**
There are three levels of conversation you may need to have about the issue itself, and a 4th relating to the *process* of the conversation.
- **Content**: The first time a problem comes up, talk about the content - the immediate pain. *If the action or the immediate consequences are the issue, you have a content problem*. This is for when it's the first time something has happened.
- **Pattern**: The next time a problem comes up, it means a pattern is starting to develop, or already has. It can be difficult to determine when something's a pattern, and when it's not, but it's important to address patterns early, before they're entrenched, and the problem becomes more difficult to address. As a general rule, the first time something happens, it's an incident. The second time, it may be coincidence. The third time, it is a pattern.
- **Relationship**: As problems continue, they can begin to impact the relationship. Relationship issues get to deeper concerns about *trust*, *competence*, or *respect*. For example, we may begin to question whether we can trust a person to keep commitments, or begin to doubt someone's technical abilities. In some cases, a relationship issue can emerge after an extreme isolated incident.
- **Process**: When communication is infrequent, it's important to talk about how you are going to communicate. How are you going to make sure that everyone has a turn to speak? How will you make space for people to pause and think.

As a general example, if you have a general problem, you can choose to view it in a few different ways.  The content ("This thing should happen") , the relationship ("I don't trust that you will make this thing happen"), or the pattern ("Issues have occurred around thing multiple times in the past"). You decide which of those issues is most important, and you make sure to discuss that, and leave other conversations for later.

Once you've broken the larger bad thing down into discrete issues, it's time to filter out all of the issues you've found through a single question: "*What do I really want?*"

**Figure out what your highest priority is, then choose the issue that stands between you and that objective.** 

#### Simplifying your topic
You should be sure you can state simple what you want to discuss. This isn't necessarily about starting the conversation, it's it's about making sure that you could explain, in a few words, what the issue you want to address is.

It's surprisingly rare for this to happen. People will often leave a problem vague, because the real root issue feels scary, and more difficult to address. Try to separate the parts of your brain that say "What's the issue", and "How can I say the issue". Those are two separate problems, and you shouldn't ignore the real root problem just because you find it scary to explain it.

If you can't simplify the topic, you probably aren't ready to have that conversation. Figure out how to simplify it, then you can decide what your next steps are.

#### What do you *really want*?
*The only person you can control directly is yourself.*

When having a discussion, you can often be driven off course by emotion, or make unhealthy decisions.

Ask yourself:
- "What do I really want for myself?"
- "What do I really want for others?"
- "What do I really want for the relationship?"

### How to Stay in Dialogue When You're Angry, Scared, or Hurt
Assumptions are incredibly dangerous. DOn't assume the feelings of others, and don't assume that your emotions are the only valid perspective on the situation. 

*When you let your emotions control your behavior, it can degrade the relationship.*

When you notice that your emotions are rising, don't try to stop them from happening or showing, instead, think through your emotions and try to process them. It's not easy to re-think your emotions into a more logical state of being, but it can be done.

#### Stories Create Feelings
In many instances, conflict comes from the fact that each person's story, or the way they view events, is incomplete, or warped by emotion. If you can recognize this in yourself, and in other people, you can get in the habit of trying to gain a greater understanding of each other, and figure out what's missing, what's making that friction. Telling a story can help shift the other person's emotions, and hearing a story can help us better re-evaluate our own story and emotions.

*personal note*: At this point in the book, I'm realizing that when we don't properly understand the other person and we don't communicate about issues, we can begin to take these points of conflict, and start to attribute them to deeper traits about the other person. EG, you could begin to think of them as "a jealous person", or "a *bad* person", when in reality, they aren't a jealous person, or a bad person (few people are), you just lack the full context.

We tell ourselves stories, even when we don't realize it. And fairly often, these stories *are not correct*. When you believe you are at risk of something, you'll often instantly create a story, or a perspective that's simplistic, and usually harmful. "I didn't do anything wrong", or "That person is just an x", or "It was all my fault", or "I deserved that". These stories are lacking the nuance real life has, and prevent you from addressing the issue in a thoughtful way.

However, any set of facts can be used to create an infinite number of stories, so it's up to you to find the right story to describe the situation.

One way to do this is to slow down, and retrace your actions:
- **Act**: Notice your behavior; ask "Am I *acting* out my concerns rather then *talking* them out?*"
- **Feel**: Put your feelings into words; ask "What emotions are encouraging me to act this way?"
- **Tell story**: Analyze your stories; ask "What story is creating these emotions?"
- **See/hear**: Get back to the facts; Ask "What have I seen or heard that *supports* this story? What have I seen or heard that *conflicts* with this story?"

Some ways to know if you need to stop, slow down, and retrace your actions include:
1. **Bad results.** You're not happy with the outcome of the discussion, you feel like it didn't properly address the issue.
2. **Tough emotions.** You're feeling strong, negative, emotions. If you're angry, stop, slow down, and ask *why*. Why are you feeling this way? Why are you acting this way? Are these feelings helping you address the conversation better? Aggressive behavior is rarely the right answer.

#### Put your feelings into words
Most individuals are shockingly bad at properly naming their emotions. They might be able to categorize them into broad categories like "bad", or "angry", but most people couldn't properly recognize, then verbalize that they're feeling a mixture of embarrassment or surprise. The distinction between knowing that you're feeling angry, and knowing that you're just embarrassed and startled might not seem big, but it has a real impact on the way you act, and the way other people will respond to you telling them that you're angry.

When you take the time to properly identify what you're feeling, and why, it creates a degree of separation between you and the emotion. This can help you more honestly look at both sides of the story.