Proteins are large, complex, organic molecules made up of **amino acids**.
	- Contain carbon, hydrogen, oxygen, and nitrogen
	- Found in plants, animals, bacteria, and viruses
- Major functions of protein in the body:
	- To build new cells and many parts of cells
	- As a component in hardened structures like hair and nails
	- As enzymes to speed chemical reactions
	- As lubricants to ease movement
	- In clotting compounds in blood
	- To build antibodies that fight disease organisms
	- As compounds that help maintain fluid and pH balance
	- As transporters
	- To make certain hormones
	- As an energy source (as a last resort)
# Introduction
- By helping to maintain fluid balance, proteins prevent **edema** (accumulation of fluid in tissues
- Proteins also help maintain **acid-base balance**.
	- Maintaining the proper pH of body fluids
	- Acts as a buffer

# Amino acids
- Amino acids are nitrogen containing chemical units that comprise proteins
- There are 20 different amino acids found in the proteins of the human body
- Each amino acid has a carbon atom that anchors
	- Hydrogen atom
	- Amino or nitrogen containing group
	- R group (side chain)
	- carboxylic acid group
- nonessential amino acids are a group of amino acids that the body can make
- Essential amino acids are amino acids the body cannot make or cannot make enough of to meet its needs
- Conditionally essential amino acids are the amino acids the body cannot make or cannot make enough of to meet its needs
- There are 9 essential acids and 11 non-essential acids

| Essential                    | Nonessential  |
| ---------------------------- | ------------- |
| Histidine                    | Alanine       |
| Isoleucine                   | Aspartic acid |
| Leucine                      | Asparagine    |
| Lysine                       | Glutanic acid |
| Methionine                   | Serine        |
| Phenylanaline                | Argine        |
| Threonine                    | Cysteine      |
| Tryptophan (extra important) | GLutamine     |
| Valine                       | Glycine       |
|                              | Proline       |
|                              | Tyrosine      |
TT HILL MVP

# Synthesis
A specific order of amino acids is needed to formulate a protein. 

# DNA
- DNA (deoxyribonucleic acid) provides instructions for making proteins.
	- **Genes** are a portion of DNA
	- To make proteins, cells assemble amino acids into specific sequences according to information from DNA
- A **peptide bond** is a chemical attraction that connects two amino acids together

# DNA Process
1. Protein synthesis begins when a section of DNA unwinds, exposing a single portion (a gene). The gene contains coded info about the order of amino acids that comprise a specific protein
2. The gene undergoes **transcription**, that is, the sequence of amino acids copied is copied in a special manner, forming **messenger  RNA** (mRNA) in the process.
3. mRNA transforms the information concerning the amino acid sequence form the nucleus to **ribosomes**, protein manufacturing sites in cytoplasm.
4. During the **translation** process, ribosomes "read" mRNA. The coded instructions indicate which amino acid to add to the polypeptide chain and its sequence.
5. Each specific **transfer RNA** (tRNA) molecule conveys a particular amino acid to the ribosome.
6. At the ribosome, the amino acid that has been delivered by the tRNA attaches to the peptide chain, lengthening it. 
7. When the translation process is complete, the ribosome release the polypeptide, and the new protein generally undergoes further processing at other sites within the cytoplasm.

Summary:
- Transcription: DNA unwinds, gene gets copied forming mRNA, happens in the nucleus
	- DNA -> mRNA
- Translation: mRNA give info to ribosomes and they "read" mRNA. trNA gets each amino acid and brings it to the ribosome to be attached to the peptide chain. Happens in **cytoplasm**.
	- mRNA -> ribosomes, ribosomes read mRNA -> tRNA grabs the amino acid needed -> ribosomes create peptide chain

# Protein Structure
- The shape of protein is important because it influences the compound's function
- Sickle cell anemia is an inherited form of anemia.
- **Denaturation** alters a protein's natural shape and function by exposing it to conditions such as heat, acids, and physical agitation. This change is permanent. 

# In Foods
- Animal foods generally provide higher amounts of protein than similar quantities of plant foods.
- Certain parts of plants provide more protein than other parts
	- Seeds, tree nuts, legumes supply more
	- Fruits or edible leaves, roots, flowers, and stems of vegetables provide less
- Legumes are parts of plants that produce pods with a single row of seeds.
	- Peas
	- Peanuts
	- Lentils
	- Soybeans
- High quality (complete) protein is a protein that contains all essential amino acids in amounts that support the deposition of protein in tissues and the growth of a young person.
	- Meat, fish, poultry, eggs, **milk**
- Low quality (incomplete) protein is a protein that lacks or has inadequate amounts of one or more of the essential amino acids
- A limiting amino acid is the essential amino acid found in the lowest concentration of a particular protein source\

- A healthy adult's RDA for protein is **0.8 g/kg** (apparently low)
- Protein needs increase during
	- Pregnancy
	- Breastfeeding
	- Periods of rapid growth
	- Recovery
		- Serious illness
		- Blood losses
		- Burns

# Digestion
- Protein digestion begins in the stomach
- Hydrochloric acid denatures food proteins and activates pepsin
	- Gastric enzymes that break proteins down into smaller polypeptides
- After polypeptides enter the small intestine, the pancreas secretes protein splitting enzymes.
- Trypsin and chymotrypsin
- Enzymes released by absorptive cells break down shortened peptides into dipeptides and tripeptides
	- Two and three amino acids respectively
- Amino acids are carried to absorptive cells by carrier systems
- After absorption, amino acids enter the capillary of villus
	- Travel to liver via hepatic portal vein
	- Liver keeps some amino acids
		- Release the rest into circulation
- Protein turnover is the cellular process of breaking down proteins and recycling their amino acids.
	- Endogenous is a source of nitrogen from within the body
	- Exogenous is a source of nitrogen from outside the body
		- Dietary protein
- **Deamination** is the removal of nitrogen-containing group from an amino acid.
- A carbon skeleton is the remains of an animo acid following deanimation and removal of the nitrogen containing component of the amino acid. Can be used to create glucose, energy, or fatty acids.
- Transamination is the transfer of the nitrogen containing group from an unneeded amino acid to a carbon skeleton to form an amino acid.
- Blood urea nitrogen (BUN) is a measure of the concentration of urea in blood.
	- Assesses kidney function
	- Normal values are from 7-20 mg/dL
- Urine urea nitrogen (UUN) is a measure of the concentration of urea in urine
	- Can be used as a marker of protein intake
	- Normal values are from 12 to 20 g in a 24 hour sample.
- Nitrogen balance or nitrogen equilibrium is the balancing of nitrogen intake with nitrogen losses
- Positive nitrogen balance is the state in which the body retains more nitrogen than it loses
- Negative nitrogen balance is the state in which the body loses more nitrogen than it retains.

# Meeting needs
- Protein comprises about 15% of the typical American's total energy intake
	- **AMDR is 10-35%**
- Complementary combinations is the mixing of certain plant foods to provide all essential amino acids without adding animal products
	- Plant foods are poor sources of one or more essential amino acids

# Malnutrition
- High amounts of animal proteins and saturated fat is associated with:
	- Heart disease
	- Colorectal cancer
	- Prostate cancer
- Consumption of red and processed meats is associated with cancers of the:
	- Pancreas
	- Stomach
	- Esophagus
	- Breast
- **High protein diets may lead to**
	- Urinary loss of calcium
	- Osteoporosis
	- Dehydration
	- Poor kidney health
- **Undernutrition** is the lack of food
	- Widespread in poor nations
- **Protein-eneregy malnutrition (PEM)** occurs where the diet lacks sufficient protein and energy
	- Edema is a sign of PEM
- **Kwashiorkor** is a form of undernutrition that results from consuming adequate energy and insufficient high quality protein
- Symptoms in children include:
	- Stunted growth
	- Blond, sparse, brittle, hair
	- Patches of skin that have lost normal coloration
	- Swollen cheeks, arms, legs, and belly
- **Marasmic kwashiorkor** is a form of undernutrition that results in a child with kwashiorkor who then starts to not consume enough energy; characterized by edema and wasting
- Marasmus is a form of undernutrition that results from starvation; diet lacks energy and nutrients
	- Loss of subcutaneous fat and deeper fat stores

# Food allergies
- A food allergy is an inflammatory response that results when the immune system reacts inappropriately to an allergen in a food
	- Allergen is usually a protein
- Some protein in food does not undergo complete digestion
	- Immune cells mount a defensive response
- Signs and symptoms of a food allergy include:
	- Hives
	- Swollen, itchy lips
	- Eczema
	- Difficulty swallowing
	- Wheezing and difficulty breathing
	- Abdominal pain
	- Vomiting
	- Diarrhea
- Top food allergens in the US include:
	- Cow's milk
	- Crustacean shellfish
	- Eggs
	- Fish
	- Peanuts
	- Sesame
	- Soybeans
	- Tree nuts
	- Wheat
- Food intolerances are unpleasant physical reactions following consumption of certain foods, symptoms include:
	- Skin flushing
	- Hives
	- Difficulty swallowing
	- Vomiting
	- Diarrhea
	- Dizziness
	- Headache
- Phenylketonuria is a genetic metabolic disorder characterized by the inability to convert the amino acid phenylalanine to tyrosine, resulting in an accumulation of phenylalanine.
- Celiac disease and gluten sensitivity
	- Celiac disease is an inherited condition in which the protein gluten cannot be absorbed, resulting in damage to the small intestine and poor absorption of nutrients.
	- Gluten is a type of protein found in many grains, provides texture and shape to baked products